Learn R Programming

ernm (version 1.0.4)

taperedErnmLikelihood: Ernm likelihood for a TaperedModel

Description

This function approximates the likelihood around a sample generated at parameters theta0. The likelihood is only "trusted" within a vicinity of theta0. The size of this vicinity is controlled by requiring a minimum effective sample size (minESS) at theta + (theta - tehta0) * damping.

Usage

taperedErnmLikelihood(
  theta,
  centers,
  tau,
  sample,
  theta0,
  stats,
  minEss = 5,
  damping = 0.05
)

Value

a list with value, gradient, and hessian

Arguments

theta

parameters

centers

center of statistics

tau

tapering parameter

sample

mcmc sample

theta0

parameter values which generated sample

stats

observed statistics

minEss

minimum effective sample size

damping

a damping parameter