This function approximates the likelihood around a sample generated at parameters theta0. The likelihood is only "trusted" within a vicinity of theta0. The size of this vicinity is controlled by requiring a minimum effective sample size (minESS) at theta + (theta - tehta0) * damping.
taperedErnmLikelihood(
theta,
centers,
tau,
sample,
theta0,
stats,
minEss = 5,
damping = 0.05
)a list with value, gradient, and hessian
parameters
center of statistics
tapering parameter
mcmc sample
parameter values which generated sample
observed statistics
minimum effective sample size
a damping parameter